==> ToolChain_STM32_1.0.25.tar.bz: ToolChain_STM32/ToolChain/install_08_Ethernet_uIP.sh <==
#!/bin/bash

#
#  Install script for Ethernet module STE101P on Olimex prototype board STM32-P107.
#  URL: http://olimex.com/dev/stm32-p107.html
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="Ethernet_uIP_STE101P"
dir $INSTALLPATH
cd $INSTALLPATH

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

if [ ! -e OK.Install ]; then #{
  echo "installing in $INSTALLPATH ..."
  InstallDir=`pwd`
  
  InstallInHomeDir="1"
  if [ "$InstallInHomeDir" == "1" ]; then
    Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
  else
    findPrefix    # install for all users
  fi
  
  get 'http://www.sics.se/~adam/download/?f=' uip-1.0-refman.pdf "TCP-IP_Stack_uIP_Manual.pdf" "../../Documentation/"
  File="STM32-P107_ethernet_demo_5.50"
  get http://olimex.com/dev/soft/arm/ST/STM-P107/ ${File}.zip
  unZIP  $File ${File}.zip
  #add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$File"
  
  if [ ! -d ${File} ]; then
    echo "ERROR: Cannot download file (folder ${File} not found in `pwd`)!"
    exit 5
  fi
  #cd ${File}/
  if [ -d ${File} ]; then
    cd "${File}"
    File="Ethernet/app/uip-conf.h"
    if [ ! -e "${File}_orig" ]; then #{
        makeOrig ${File}
        echo "`pwd`> modifing ${File}.. (disabling double definitions)"
    
        replaceInFile ${File} 'typedef uint8_t u8_t;'     '#include "stm32_io.h" //ToolChain_STM32 already define in STM32_io.h  typedef uint8_t u8_t;'
        replaceInFile ${File} 'typedef uint16_t u16_t;'   '//ToolChain_STM32 already define in STM32_io.h  typedef uint16_t u16_t;'
        #replaceInFile ${File} ''                         '//ToolChain_STM32 already define in STM32_io.h  '
        
    fi #}
    
    File="Ethernet/app/ethernet.h"
    if [ ! -e "${File}_orig" ]; then #{
      makeOrig ${File}
      echo "`pwd`> modifing ${File}.. (disabling double definitions)"
  
      replaceInFile ${File} '#include "httpd.h"'     '//ToolChain_STM32 httpd not required for minimal TCP/IP - #include "httpd.h"'
      
    fi #}
    cd $InstallDir
    
    echo "" >OK.Install
  fi
fi #} [ ! -e OK.Install ]; then
if [   -e OK.Install ]; then #{
  cat <<END_OF_MAKEFILE >../extensions/makefile.$INSTALLPATH
#
#                               ToolChain_STM32
#
#                         Extension to central makefile
#
#                   makefile written by Gregor Rebel 2010-2011
#

EXTENSION_$INSTALLPATH = 1

#EXTENSION_HTTP_SERVER = 1   # activate to include this feature!

ifdef EXTENSION_$INSTALLPATH
  ifndef uCONTROLLER
    STM32F10X_CL   =1
  endif
  
  ifndef STM32F10X_CL
    ERROR: STM32F10X_CL_must_be_set!
  endif

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$INSTALLPATH

INCLUDE_DIRS += -I Ethernet_Demo/Libraries/STM32_ETH_Driver/inc/ \
                -I Ethernet_Demo/Ethernet/uip/ \
                -I Ethernet_Demo/Ethernet/app/ \
                -I Ethernet_Demo/Ethernet/uip/httpd/

VPATH += Ethernet_Demo/Libraries/STM32_ETH_Driver/src/ \
         Ethernet_Demo/Ethernet/app \
         Ethernet_Demo/Ethernet/uip


MAIN_OBJS += stm32_eth.o clock-arch.o ethernet.o timer.o uip.o uip_arp.o uiplib.o misc.o sbrk.o

ifdef EXTENSION_HTTP_SERVER

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_HTTP_SERVER

VPATH += Ethernet_Demo/Ethernet/uip/httpd/
MAIN_OBJS += httpd-fs.o http-strings.o httpd.o httpd-cgi.o psock.o

endif

endif
END_OF_MAKEFILE

  addLine ../scripts/createLinks.sh "rm 2>/dev/null Ethernet_Demo_uIP;     ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/STM32-P107_ethernet_demo_5.50/           Ethernet_Demo_uIP"
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

cd ..

#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.27.tar.bz: ToolChain_STM32/ToolChain/install_08_Ethernet_uIP.sh <==
#!/bin/bash

#
#  Install script for Ethernet module STE101P on Olimex prototype board STM32-P107.
#  URL: http://olimex.com/dev/stm32-p107.html
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="ethernet_uip_ste101p"
dir $INSTALLPATH
cd $INSTALLPATH

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

if [ ! -e OK.Install ]; then #{
  echo "installing in $INSTALLPATH ..."
  InstallDir=`pwd`
  
  InstallInHomeDir="1"
  if [ "$InstallInHomeDir" == "1" ]; then
    Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
  else
    findPrefix    # install for all users
  fi
  
  get 'http://www.sics.se/~adam/download/?f=' uip-1.0-refman.pdf "TCP-IP_Stack_uIP_Manual.pdf" "../../Documentation/"
  File="STM32-P107_ethernet_demo_5.50"
  get http://olimex.com/dev/soft/arm/ST/STM-P107/ ${File}.zip
  unZIP  $File ${File}.zip
  #add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$File"
  
  if [ ! -d ${File} ]; then
    echo "ERROR: Cannot download file (folder ${File} not found in `pwd`)!"
    exit 5
  fi
  #cd ${File}/
  if [ -d ${File} ]; then
    cd "${File}"
    File="Ethernet/app/uip-conf.h"
    if [ ! -e "${File}_orig" ]; then #{
        makeOrig ${File}
        echo "`pwd`> modifing ${File}.. (disabling double definitions)"
    
        replaceInFile ${File} 'typedef uint8_t u8_t;'     '#include "stm32_io.h" //ToolChain_STM32 already define in STM32_io.h  typedef uint8_t u8_t;'
        replaceInFile ${File} 'typedef uint16_t u16_t;'   '//ToolChain_STM32 already define in STM32_io.h  typedef uint16_t u16_t;'
        #replaceInFile ${File} ''                         '//ToolChain_STM32 already define in STM32_io.h  '
        
    fi #}
    
    File="Ethernet/app/ethernet.h"
    if [ ! -e "${File}_orig" ]; then #{
      makeOrig ${File}
      echo "`pwd`> modifing ${File}.. (disabling double definitions)"
  
      replaceInFile ${File} '#include "httpd.h"'     '//ToolChain_STM32 httpd not required for minimal TCP/IP - #include "httpd.h"'
      
    fi #}
    cd $InstallDir
    
    echo "" >OK.Install
  fi
fi #} [ ! -e OK.Install ]; then
if [   -e OK.Install ]; then #{
  cat <<END_OF_MAKEFILE >../extensions/makefile.$INSTALLPATH #{
#
#                               ToolChain_STM32
#
#                         Extension to central makefile
#
#                   makefile written by Gregor Rebel 2010-2011
#

EXTENSION_$INSTALLPATH = 1

#EXTENSION_HTTP_SERVER = 1   # activate to include this feature!

ifdef EXTENSION_$INSTALLPATH
  ifndef uCONTROLLER
    STM32F10X_CL   =1
  endif
  
  ifndef STM32F10X_CL
    ERROR: STM32F10X_CL_must_be_set!
  endif

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$INSTALLPATH

INCLUDE_DIRS += -I additionals/ethernet_demo_uip/common/STM32_ETH_Driver/inc/ \\
                -I additionals/ethernet_demo_uip/Ethernet/uip/ \\
                -I additionals/ethernet_demo_uip/Ethernet/app/ \\
                -I additionals/ethernet_demo_uip/Ethernet/uip/httpd/

VPATH += ethernet_demo_uip/common/STM32_ETH_Driver/src/ \\
         ethernet_demo_uip/Ethernet/app \\
         ethernet_demo_uip/Ethernet/uip


MAIN_OBJS += stm32_eth.o clock-arch.o ethernet.o timer.o uip.o uip_arp.o uiplib.o misc.o sbrk.o

ifdef EXTENSION_HTTP_SERVER

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_HTTP_SERVER

VPATH += ethernet_demo_uip/Ethernet/uip/httpd/
MAIN_OBJS += httpd-fs.o http-strings.o httpd.o httpd-cgi.o psock.o

endif

endif
END_OF_MAKEFILE
#}

  addLine ../scripts/createLinks.sh "rm 2>/dev/null ethernet_demo_uip;     ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/STM32-P107_ethernet_demo_5.50/           ethernet_demo_uip"
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

cd ..

#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
